@@ -616,19 +616,16 @@ ephy_spinner_init (EphySpinner *spinner)
 	details->need_load = TRUE;
 }
 
-static int
-ephy_spinner_expose (GtkWidget *widget,
-		     GdkEventExpose *event)
+static gboolean
+ephy_spinner_draw (GtkWidget *widget,
+                   cairo_t *cr)
 {
 	EphySpinner *spinner = EPHY_SPINNER (widget);
 	EphySpinnerDetails *details = spinner->details;
 	EphySpinnerImages *images;
 	GtkAllocation allocation;
 	GdkPixbuf *pixbuf;
-	GdkWindow *window;
-	GdkGC *gc;
 	int x_offset, y_offset, width, height;
-	GdkRectangle pix_area, dest;
 
 	if (!gtk_widget_is_drawable (GTK_WIDGET (spinner)))
 	{
@@ -664,26 +661,8 @@ ephy_spinner_expose (GtkWidget *widget,
 	gtk_widget_get_allocation (widget, &allocation);
 	x_offset = (allocation.width - width) / 2;
 	y_offset = (allocation.height - height) / 2;
-
-	pix_area.x = x_offset + allocation.x;
-	pix_area.y = y_offset + allocation.y;
-	pix_area.width = width;
-	pix_area.height = height;
-
-	if (!gdk_rectangle_intersect (&event->area, &pix_area, &dest))
-	{
-		return FALSE;
-	}
-
-	window = gtk_widget_get_window (widget);
-	gc = gdk_gc_new (window);
-	gdk_draw_pixbuf (window, gc, pixbuf,
-			 dest.x - x_offset - allocation.x,
-			 dest.y - y_offset - allocation.y,
-			 dest.x, dest.y,
-			 dest.width, dest.height,
-			 GDK_RGB_DITHER_MAX, 0, 0);
-	g_object_unref (gc);
+	gdk_cairo_set_source_pixbuf (cr, pixbuf, x_offset, y_offset);
+	cairo_paint (cr);
 
 	return FALSE;
 }
@@ -880,7 +859,7 @@ ephy_spinner_class_init (EphySpinnerClass *class)
 	object_class->dispose = ephy_spinner_dispose;
 	object_class->finalize = ephy_spinner_finalize;
 
-	widget_class->expose_event = ephy_spinner_expose;
+	widget_class->draw = ephy_spinner_draw;
 	widget_class->size_request = ephy_spinner_size_request;
 	widget_class->map = ephy_spinner_map;
 	widget_class->unmap = ephy_spinner_unmap;
